@@ -25,7 +25,7 @@ class Roi:
 
     def full(shape):
         """ Roi with same shape as shape """
-        [h, w] = shape
+        h, w = shape
         return Roi([0, h, 0, w, h, w])
 
     def find_from_mask(mask):
@@ -165,7 +165,7 @@ class Roi:
         if self.empty() or len(self.roi) == 4:
             return None
         else:
-            return self.roi[4:]
+            return tuple(self.roi[4:])
 
     def shape(self):
         h = self.roi[1] - self.roi[0]
